changeset 104882:3fea2465f700

(Vtruncate_partial_width_windows): Improve docstring.
author Stefan Monnier <monnier@iro.umontreal.ca>
date Wed, 09 Sep 2009 01:21:10 +0000
parents 98356e8ba345
children aa07c84cb085
files src/xdisp.c
diffstat 1 files changed, 4 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/src/xdisp.c	Tue Sep 08 19:47:07 2009 +0000
+++ b/src/xdisp.c	Wed Sep 09 01:21:10 2009 +0000
@@ -24862,13 +24862,13 @@
 
   DEFVAR_LISP ("truncate-partial-width-windows",
 	       &Vtruncate_partial_width_windows,
-    doc: /* Non-nil means truncate lines in windows with less than the frame width.
-For an integer value, truncate lines in each window with less than the
+    doc: /* Non-nil means truncate lines in windows narrower than the frame.
+For an integer value, truncate lines in each window narrower than the
 full frame width, provided the window width is less than that integer;
 otherwise, respect the value of `truncate-lines'.
 
-For any other non-nil value, truncate lines in all windows with
-less than the full frame width.
+For any other non-nil value, truncate lines in all windows that do
+not span the full frame width.
 
 A value of nil means to respect the value of `truncate-lines'.